#
# spec file for package pantheon-photos
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pantheon-photos
Version:        0.2.4
Release:        lp150.1.7
Summary:        Photo manager for Elementary OS
License:        GPL-2.0 and LGPL-2.1
Group:          Productivity/Graphics/Viewers
Url:            https://launchpad.net/pantheon-photos
Source:         https://launchpad.net/pantheon-photos/0.2.x/%{version}/+download/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  elementary-icon-theme
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(geocode-glib-1.0)
BuildRequires:  pkgconfig(gexiv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libgphoto2)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(rest-0.7)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vapigen) >= 0.28.0
BuildRequires:  pkgconfig(webkit2gtk-4.0)
Recommends:     %{name}-lang
Conflicts:      shotwell
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%glib2_gsettings_schema_requires

%description
pantheon-photos is a digital photo organizer based on Shotwell and
designed for the Elementary OS environment. It allows you to import
photos from disk or camera, organize them in various ways, view them
in full-window or fullscreen mode, and export them to share with
others.

%lang_package

%prep
%setup -q

sed -e 's/\/metainfo/\/appdata/' \
	-e 's|\$.CMAKE_INSTALL_FULL_LIBEXECDIR.|%{_libexecdir}|' \
    -i $(grep -rwl 'CMAKE_INSTALL_FULL_LIBEXECDIR\|metainfo')

%build
%cmake \
    -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed" \
    -DGSETTINGS_COMPILE=OFF

make %{?_smp_mflags}

%install
%cmake_install

# Workaround https://bugzilla.opensuse.org/show_bug.cgi?id=561846
pushd %{buildroot}
for _icon in $(find -name \*.desktop* | xargs sed -n '/Icon/s/^.*\=//p'); do
    _icon=${_icon##*/}
    if ! find -name "$_icon" | grep -q .; then
      _icon=$(find %{_datadir}/icons -name "${_icon%.*}.svg" | sort | head -n1)
      install -Dm0644 \
        "$_icon" ".%{_datadir}/icons/hicolor/scalable/apps/${_icon##*/}"
    else
      exit 1
    fi
done
popd

%find_lang %{name} %{?no_lang_C} %{name}.lang
%fdupes %{buildroot}%{_datadir}

%post
%icon_theme_cache_post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%glib2_gsettings_schema_postun

%files
%defattr(-,root,root)
%doc AUTHORS COPYING
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_libexecdir}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/org.pantheon.photos*.desktop
%{_datadir}/icons/hicolor/*/apps/multimedia-photo*.??g
%{_datadir}/glib-2.0/schemas/org.pantheon.photos*.xml
%{_datadir}/appdata/org.pantheon.photos.appdata.xml
%dir %{_datadir}/appdata

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 0.2.4:
  * remove about dialog (#158)
  * AppWindow.vala: code style (#159)
  * Update appdata URLs and summary (#157)
  * Create .gitignore (#156)
  * Create CODE_OF_CONDUCT.md (#155)
* Tue Jul 11 2017 bwiedemann@suse.com
- Sort file lists to always install the same .svg size
  to fix build-compare (boo#1041090)
* Wed May  3 2017 avvissu@yandex.by
- Update to 0.2.3:
  * Update URLs (#145)
  * correct undo button position in header bar (#140)
  * Add Travis CI (#144)
  * Update README.md; remove old files (#139)
  * Switch to new comparators
* Tue Mar 21 2017 avvissu@yandex.by
- Update to 0.2.2:
  * appdata: add x-appcenter-color-primary
  * Resources.vala: Remove unused code
  * ExportDialog.vala:
  * Better variable names
  * GObject-style construction
  * Code style
  * Don't nest boxes
  * Fix Dialog margins
  * Spacing and alignment
  * Properties, not impure functions
  * Remove unused MultiTextEntryDialog.vala
  * Dialogs.vala: Remove unused class MultiTextEntryDialogMediator
  * Remove top.ui
  * LibraryWindow.vala: Remove reference to top.ui
  * Split Dialogs.vala into one file per class in a new Dialogs
    folder
  * Deleted UI files leftovers
  * Remove executable bit from files
  * Move all the context menus to Vala
  * Do not use UI file for the trash toolbar. Empty the trash is
    now a view action.
  * Remove unused desktop background slideshow dialog
  * appdata: initialize entries for future release
  * Preserve metadata when opening photo directly from the
    filesystem
  * see if a file is writeable when closing and offer save as if
    the file is read only
  * Removed leftover from previous merges
  * Fix deprecation warnings
  * Remove unused constants from config.vala
  * Replace Cairo drawing in CheckBoardLayout with Gtk.CSS
  * Simplified the GtkAction creation
  * Install the AppData into the right folder
  * Use the right libexec directory for the thumbnailer
* Thu Jan 26 2017 jengelh@inai.de
- Rewrite description
* Wed Jan 25 2017 avvissu@yandex.by
- Update to 0.2.1.1:
  * Fix appdata versions
  * Launchpad automatic translations update.
  * Database code cleanup
* Tue Jan 17 2017 avvissu@yandex.by
- Update to 0.2.1:
  * Set window icon name
  * Replace the drag nub png with an svg
  * Make Ctrl + S work in the photo viewer
  * update translation template
  * Fix deprecation warnings with Soup Status
  * Update license headers to pass licensecheck
  * Add non-standard icons to a gresource
  * Add noninterpretable video bg and drag nub to the resource
  * Remove unused code from CustomComponents.vala
  * Don't install icons to filesystem since they're compiled into
    the gresource
  * Updated appdata.xml to reflect the last MRs of Kirill (r3100
    and r3101.
  * Left bracket key rotates counterclockwise (lp#1653662)
  * Grab focus so arrow key navigation works (lp#1631607)
  * Add Gif support
  * Remove the "sprocket" from video thumbnails and replace the
    thumbnail image
  * Properties.vala: Subclass Gtk.Label into PropertiesLabel and
    PropertiesHeader
  * BasicProperties.vala: Use Propertiesheader and PropertiesLabel
  * Fix build of r3072
  * Fix segmentation fault in RawsPage.vala (triggered by
    clicking Raw Photos in the sidebar) and CollectionPage.vala
  * Update COPYING with Photos name and rewrite INSTALL
  * Remove unused libunique VAPI
  * Resources.vala: Remove unused constants
  * Properties.vala: Remove unused get_header_title
  * Fix deprecation warnings about Gdk.Cursor
  * Fix for segmentation fault on right clicking a video file in
    the Photos Library
  * Remove use of Gtk.Stock
  * Update README
  * BasicProperties.vala:
  * Title can't be null so don't check for it
  * Use attach for items instead of add_line
  * Code style
  * Metadata Sidebar: Get a human-readable location from gps data
  * Fix URLs in Resources.vala
  * EditableTitle: Stop editing on focus out
  * BasicProperties.vala: Create duration label without mystery
    meat method
  * update transation template
  * BasicProperties.vala: Add Exposure Bias and Flash to the
    flowbox
  * ExtendedProperties.vala: Remove Exposure Bias and Flash
  * BasicProperties.vala: Show date and time in a single line
  * LibraryProperties.vala:
  * Use row spacing, not empty grids
  * Pack widgets directly
  * Put textview in a frame
  * No CSS weirdness
  * MetadataSidebar.vala: Remove the expanders
  * BasicProperties.vala: Add camera make and model as a single
    line above other camera-related info
  * ExtendedProperties.vala: Remove camera make and model
  * BasicProperties.vala: Add filesize and combine it with
    dimensions a la Files
  * ExtendedProperties.vala: Remove filesize
  * ExtendedProperties.vala: Remove superfluous properties
  * EditableTitle.vala: Give the label h3
  * BasicProperties.vala: Add the title entry to the top of this
    box
  * LibraryProperties.vala: Remove the title entry from this box
  * MetadataSidebar.vala: Move basic properties to the top
  * Remove Flag action from the sidebar
  * LibraryProperties: Change title entry for an EditableTitle
  * BasicProperties.vala: Create a flowbox with exif data and
    nice little icons
  * Use -symbolic variant of media-playback-start
  * Properties.vala: Remove unused bool multi_line
  * Fix syntax errors to make it compilable with valac 0.35+
  * Properties.vala:
  * Vala-style properties
  * Update license header
  * de-duplicate conditionals
  * Brackets
  * Don't try to mess with the stylesheet
  * MetadataSidebar.vala:
  * Don't create widgets in declaration
  * Only set the scrollbar policy we intend to
  * Organize properties
  * Use brackets
  * Stack instead of notebook
  * Whitespace
  * sidebar/Tree.vala:
  * Don't declare a constant you only use once
  * let Gtk handle scaling so we don't double scale
  * Add releases info to appdata.xml
  * Split editing tools into separate files
  * Kill the search revealer in favor of Search entry
  * Remove rating system
  * Set AppID to org.pantheon.photos
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.2
* Mon Dec 14 2015 and.november@opensuse.org
- update to version 0.1.1
* Mon Sep  7 2015 and.november@opensuse.org
- initial package
